# MainShortcuts2
[![Build and upload release](https://github.com/MainPlay-TG/MainShortcuts2.py/actions/workflows/build.yml/badge.svg)](https://github.com/MainPlay-TG/MainShortcuts2.py/actions/workflows/build.yml)
<a href="https://pypi.org/project/MainShortcuts2/"><img alt="PyPi" src="https://img.shields.io/pypi/format/mainshortcuts2?style=flat&label=PyPi"/></a>
## Описание
Сокращение и улучшение функций
## Установка
Для установки через `pip` используйте
```bash
python3 -m pip install -U MainShortcuts2
```
## Использование
Импорт модуля
```python
from MainShortcuts2 import ms
```
Встроенная информация о модуле
```python
ms.version -> str # Версия модуля
```
-# README в разработке, это оказалось сложнее, чем писать сам модуль